## 概要
Raspberry Pi用 サーボモータードライバー基板RPZ-RC-Servoを制御するソフトウェアです。
Pythonパッケージを使うことでご自身のプログラムからRCサーボモーターを制御することができます。


## 使い方
使い方は、以下をご参照下さい。
- [RPZ-RC-Servo製品ページ](https://www.indoorcorgielec.com/products/rpz-rc-servo)
- [サーボモーターを指定した角度に動かす](https://www.indoorcorgielec.com/resources/raspberry-pi/rpz-rc-servo-control)
- [PCA9685データシート](https://www.nxp.jp/products/power-management/lighting-driver-and-controller-ics/led-controllers/16-channel-12-bit-pwm-fm-plus-ic-bus-led-controller:PCA9685)